OPACK_DEBUG=yes
# Enable debugging mode if OPACK_DEBUG is set to 'yes'

ifndef OPACK_DEBUG
.SILENT:
$(info OPACK_DEBUG)
else
endif

OPACK_SYS_HOSTNAME?=	opack
# Set the hostname of the virtual machine to 'opack' if not specified

OPACK_SYS_USER?=	opack	
# Set the username for the virtual machine to 'opack' if not specified

OPACK_SYS_PASSWORD?=	opack	
# Set the password for the virtual machine to 'opack' if not specified

OPACK_SYS_DISK_SIZE?=	4096
# Set the disk size of the virtual machine to 4096 MB if not specified

OPACK_SYS_MEMORY?=	512
# Set the memory (RAM) size of the virtual machine to 512 MB if not specified

OPACK_SYS_CPU?=		1
# Set the number of CPUs for the virtual machine to 1 if not specified

OPACK_SYS_SERVER?=cdn.openbsd.org
# Set the OpenBSD package server to 'cdn.openbsd.org' if not specified

OPACK_SYS_ARCHITECTURE?=amd64
# Set the architecture for the virtual machine to 'amd64' if not specified

OPACK_SYS_RELEASE?=$(shell basename -s .html $(shell curl -s https://www.openbsd.org/ | grep released | cut -d '"' -f 2))
# Automatically determine the OpenBSD release based on the OpenBSD website

OPACK_SYS_VERSION_MAJOR=$(shell echo $(OPACK_SYS_RELEASE) | cut -c 1)
OPACK_SYS_VERSION_MINOR=$(shell echo $(OPACK_SYS_RELEASE) | cut -c 2)
OPACK_SYS_VERSION?=$(OPACK_SYS_VERSION_MAJOR).$(OPACK_SYS_VERSION_MINOR)
# Extract major and minor version components from the release and construct the version string

ifeq ($(OPACK_SYS_VERSION), snapshots)
ifeq ($(shell (curl -s https://$(OPACK_SYS_SERVER)/pub/OpenBSD/snapshots/$(OPACK_SYS_ARCHITECTURE)/SHA256 | grep cd$(OPACK_SYS_RELEASE).iso > /dev/null && echo OK) || echo KO), KO)
$(eval OPACK_SYS_RELEASE=$(shell echo $$(($(OPACK_SYS_RELEASE)+1))))
OPACK_SYS_VERSION_MAJOR=$(shell echo $(OPACK_SYS_RELEASE) | cut -c 1)
OPACK_SYS_VERSION_MINOR=$(shell echo $(OPACK_SYS_RELEASE) | cut -c 2)
endif
endif
# Check if the OpenBSD version is 'snapshots' and automatically increment it if needed

OPACK_SYS_XENOCARA?=no
# Set whether to include Xenocara (X Window System) in the virtual machine to 'no' by default

OPACK_SYS_SETS?=+* -x* +xbase* -game* -comp* -man* -bsd.rd
# Define the sets of files/packages to install in the virtual machine

OPACK_SYS_TIMEZONE?=Europe/Paris
# Set the timezone for the virtual machine to 'Europe/Paris' by default

OPACK_SYS_SSH_KEY?=$(shell curl -s https://raw.githubusercontent.com/hashicorp/vagrant/master/keys/vagrant.pub)
# Automatically fetch the Vagrant SSH key

OPACK_PACKER_VERSION?=$$(curl -s https://checkpoint-api.hashicorp.com/v1/check/packer | jq -r .current_version)
# Automatically fetch the latest Packer version

OPACK_PACKER_HTTP_DIR?=$(OPACK_PACKER_DIR)/http
# Define the Packer HTTP directory

OPACK_SYS_ISO_URL?=https://$(OPACK_SYS_SERVER)/pub/OpenBSD/$(OPACK_SYS_VERSION)/$(OPACK_SYS_ARCHITECTURE)/cd$(OPACK_SYS_RELEASE).iso
# Define the URL to fetch the OpenBSD ISO image

OPACK_SYS_ISO_SHA256SUM?=$(shell curl -s https://$(OPACK_SYS_SERVER)/pub/OpenBSD/$(OPACK_SYS_VERSION)/$(OPACK_SYS_ARCHITECTURE)/SHA256 | grep cd$(OPACK_SYS_RELEASE).iso | cut -d"=" -f2 | tr -d ' ')
# Calculate the SHA256 sum of the OpenBSD ISO image

OPACK_COMMIT?=$(shell git log --oneline -n 1 --abbrev-commit --date=short --pretty=format:"%h %ad %s" 2&>/dev/null || echo latest)
OPACK_SHORT_REV?=$(shell git rev-parse --short HEAD 2&>/dev/null || echo latest)
# Obtain Git commit information

OPACK_SYS_SETS_LOCATION?=http
# Set the location to fetch the sets from to 'http'

OPACK_NO_SIGCHK?=no
# Set whether to skip signature checking to 'no' by default

OPACK_SYS_HEADLESS?=true
# Set whether the virtual machine runs in headless mode to 'true' by default

OPACK_CACHE_DIR?=$(OPACK_DIR)cache
# Define the directory for caching

OPACK_BOX_FILE?=$(OPACK_CACHE_DIR)/$(OPACK_TARGET).box
$(info BOX $(OPACK_BOX_FILE))
# Define the path to the Vagrant box file and output info

OPACK_META_FILE?=$(OPACK_TARGET).json
# Define the metadata file for the Vagrant box

OPACK_BOX_VERSION?=1.$(shell date +%s).$(OPACK_SHORT_REV)
# Define the version of the Vagrant box

OPACK_BOX_FILE_SHA256?=XXXtoreplaceXXX
# Define the SHA256 sum for the Vagrant box file

OPACK_BOX_TAG?=opack/$(OPACK_TARGET)
# Define the Docker image tag for the Vagrant box

OPACK_PACKER_DIR?=opack_build_$(OPACK_SHORT_REV)
# Define the directory for Packer build

OPACK_PROVISION_FILE?=$(OPACK_DIR)opack-provision.sh
# Define the provisioning script for Packer

OPACK_AUTODISKLABEL_FILE?=$(OPACK_DIR)autodisklabel
# Define the autodisklabel file

OPACK_VAGRANT_FILE=Vagrantfile
# Define the Vagrantfile

OPACK_RUNTIME_PROVISION_FILE?=$(OPACK_DIR)vagrant-provision.sh
# Define the runtime provisioning script for Vagrant

ifdef OPACK_DEBUG
$(info HOSTNAME = $(OPACK_SYS_HOSTNAME) USER = $(OPACK_SYS_USER) PASSWORD = $(OPACK_SYS_PASSWORD))
$(info DISK-SIZE = $(OPACK_SYS_DISK_SIZE)m ARCH = $(OPACK_SYS_ARCHITECTURE) CPU = $(OPACK_SYS_CPU) MEMORY = $(OPACK_SYS_MEMORY)m)
$(info RELEASE = $(OPACK_SYS_RELEASE) VERSION = $(OPACK_SYS_VERSION) SERVER = $(OPACK_SYS_SERVER))
$(info X = $(OPACK_SYS_XENOCARA) SETS = $(OPACK_SYS_SETS) NO-SIGNATURE = $(OPACK_NO_SIGCHK) HEADLESS = $(OPACK_SYS_HEADLESS))
endif

